@@ -2,6 +2,7 @@ import io
 import json
 import os
 import platform
+import sys
 import requests
 from .input_file import InputFile
 from .exception import AppwriteException
@@ -14,12 +15,12 @@ class Client:
         self._endpoint = 'https://cloud.appwrite.io/v1'
         self._global_headers = {
             'content-type': '',
-            'user-agent' : f'AppwritePythonSDK/11.1.0 ({platform.uname().system}; {platform.uname().version}; {platform.uname().machine})',
+            'user-agent' : f'AppwritePythonSDK/13.6.0 ({platform.uname().system}; {platform.uname().version}; {platform.uname().machine})',
             'x-sdk-name': 'Python',
             'x-sdk-platform': 'server',
             'x-sdk-language': 'python',
-            'x-sdk-version': '11.1.0',
-            'X-Appwrite-Response-Format' : '1.7.0',
+            'x-sdk-version': '13.6.0',
+            'X-Appwrite-Response-Format' : '1.8.0',
         }
 
     def set_self_signed(self, status=True):
@@ -78,8 +79,6 @@ class Client:
         if params is None:
             params = {}
 
-        params = {k: v for k, v in params.items() if v is not None}  # Remove None values from params dictionary
-
         data = {}
         files = {}
         stringify = False
@@ -120,7 +119,7 @@ class Client:
             warnings = response.headers.get('x-appwrite-warning')
             if warnings:
                 for warning in warnings.split(';'):
-                    print(f'Warning: {warning}')
+                    print(f'Warning: {warning}', file=sys.stderr)
 
             content_type = response.headers['Content-Type']
 
