@@ -1,6 +1,7 @@
 from ..service import Service
-from typing import List, Dict, Any
+from typing import List, Dict, Any, Optional
 from ..exception import AppwriteException
+from appwrite.utils.deprecated import deprecated
 from ..enums.authenticator_type import AuthenticatorType;
 from ..enums.authentication_factor import AuthenticationFactor;
 from ..enums.o_auth_provider import OAuthProvider;
@@ -31,11 +32,10 @@ class Account(Service):
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def create(self, user_id: str, email: str, password: str, name: str = None) -> Dict[str, Any]:
+    def create(self, user_id: str, email: str, password: str, name: Optional[str] = None) -> Dict[str, Any]:
         """
         Use this endpoint to allow a new user to register a new account in your project. After the user registration completes successfully, you can use the [/account/verfication](https://appwrite.io/docs/references/cloud/client-web/account#createVerification) route to start verifying the user email address. To allow the new user to login to their new account, you need to create a new [account session](https://appwrite.io/docs/references/cloud/client-web/account#createEmailSession).
 
-
         Parameters
         ----------
         user_id : str
@@ -44,7 +44,7 @@ class Account(Service):
             User email.
         password : str
             New user password. Must be between 8 and 256 chars.
-        name : str
+        name : Optional[str]
             User name. Max length: 128 chars.
         
         Returns
@@ -85,7 +85,6 @@ class Account(Service):
         This endpoint can also be used to convert an anonymous account to a normal one, by passing an email address and a new password.
         
 
-
         Parameters
         ----------
         email : str
@@ -120,15 +119,16 @@ class Account(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def list_identities(self, queries: List[str] = None) -> Dict[str, Any]:
+    def list_identities(self, queries: Optional[List[str]] = None, total: Optional[bool] = None) -> Dict[str, Any]:
         """
         Get the list of identities for the currently logged in user.
 
-
         Parameters
         ----------
-        queries : List[str]
+        queries : Optional[List[str]]
             Array of query strings generated using the Query class provided by the SDK. [Learn more about queries](https://appwrite.io/docs/queries). Maximum of 100 queries are allowed, each 4096 characters long. You may filter on the following attributes: userId, provider, providerUid, providerEmail, providerAccessTokenExpiry
+        total : Optional[bool]
+            When set to false, the total count returned will be 0 and will not be calculated.
         
         Returns
         -------
@@ -145,6 +145,7 @@ class Account(Service):
         api_params = {}
 
         api_params['queries'] = queries
+        api_params['total'] = total
 
         return self.client.call('get', api_path, {
         }, api_params)
@@ -153,7 +154,6 @@ class Account(Service):
         """
         Delete an identity by its unique ID.
 
-
         Parameters
         ----------
         identity_id : str
@@ -204,15 +204,16 @@ class Account(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def list_logs(self, queries: List[str] = None) -> Dict[str, Any]:
+    def list_logs(self, queries: Optional[List[str]] = None, total: Optional[bool] = None) -> Dict[str, Any]:
         """
         Get the list of latest security activity logs for the currently logged in user. Each log returns user IP address, location and date and time of log.
 
-
         Parameters
         ----------
-        queries : List[str]
+        queries : Optional[List[str]]
             Array of query strings generated using the Query class provided by the SDK. [Learn more about queries](https://appwrite.io/docs/queries). Only supported methods are limit and offset
+        total : Optional[bool]
+            When set to false, the total count returned will be 0 and will not be calculated.
         
         Returns
         -------
@@ -229,6 +230,7 @@ class Account(Service):
         api_params = {}
 
         api_params['queries'] = queries
+        api_params['total'] = total
 
         return self.client.call('get', api_path, {
         }, api_params)
@@ -237,7 +239,6 @@ class Account(Service):
         """
         Enable or disable MFA on an account.
 
-
         Parameters
         ----------
         mfa : bool
@@ -270,7 +271,6 @@ class Account(Service):
         """
         Add an authenticator app to be used as an MFA factor. Verify the authenticator using the [verify authenticator](/docs/references/cloud/client-web/account#updateMfaAuthenticator) method.
 
-
         Parameters
         ----------
         type : AuthenticatorType
@@ -303,7 +303,6 @@ class Account(Service):
         """
         Verify an authenticator app after adding it using the [add authenticator](/docs/references/cloud/client-web/account#createMfaAuthenticator) method.
 
-
         Parameters
         ----------
         type : AuthenticatorType
@@ -342,7 +341,6 @@ class Account(Service):
         """
         Delete an authenticator for a user by ID.
 
-
         Parameters
         ----------
         type : AuthenticatorType
@@ -375,7 +373,6 @@ class Account(Service):
         """
         Begin the process of MFA verification after sign-in. Finish the flow with [updateMfaChallenge](/docs/references/cloud/client-web/account#updateMfaChallenge) method.
 
-
         Parameters
         ----------
         factor : AuthenticationFactor
@@ -408,7 +405,6 @@ class Account(Service):
         """
         Complete the MFA challenge by providing the one-time password. Finish the process of MFA verification by providing the one-time password. To begin the flow, use [createMfaChallenge](/docs/references/cloud/client-web/account#createMfaChallenge) method.
 
-
         Parameters
         ----------
         challenge_id : str
@@ -533,7 +529,6 @@ class Account(Service):
         """
         Update currently logged in user account name.
 
-
         Parameters
         ----------
         name : str
@@ -562,16 +557,15 @@ class Account(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def update_password(self, password: str, old_password: str = None) -> Dict[str, Any]:
+    def update_password(self, password: str, old_password: Optional[str] = None) -> Dict[str, Any]:
         """
         Update currently logged in user password. For validation, user is required to pass in the new password, and the old password. For users created with OAuth, Team Invites and Magic URL, oldPassword is optional.
 
-
         Parameters
         ----------
         password : str
             New user password. Must be at least 8 chars.
-        old_password : str
+        old_password : Optional[str]
             Current user password. Must be at least 8 chars.
         
         Returns
@@ -602,7 +596,6 @@ class Account(Service):
         """
         Update the currently logged in user's phone number. After updating the phone number, the phone verification status will be reset. A confirmation SMS is not sent automatically, however you can use the [POST /account/verification/phone](https://appwrite.io/docs/references/cloud/client-web/account#createPhoneVerification) endpoint to send a confirmation SMS.
 
-
         Parameters
         ----------
         phone : str
@@ -662,7 +655,6 @@ class Account(Service):
         """
         Update currently logged in user account preferences. The object you pass is stored as is, and replaces any previous value. The maximum allowed prefs size is 64kB and throws error if exceeded.
 
-
         Parameters
         ----------
         prefs : dict
@@ -695,7 +687,6 @@ class Account(Service):
         """
         Sends the user an email with a temporary secret key for password reset. When the user clicks the confirmation link he is redirected back to your app password reset URL with the secret key and email address values attached to the URL query string. Use the query string params to submit a request to the [PUT /account/recovery](https://appwrite.io/docs/references/cloud/client-web/account#updateRecovery) endpoint to complete the process. The verification link sent to the user's email address is valid for 1 hour.
 
-
         Parameters
         ----------
         email : str
@@ -736,7 +727,6 @@ class Account(Service):
         
         Please note that in order to avoid a [Redirect Attack](https://github.com/OWASP/CheatSheetSeries/blob/master/cheatsheets/Unvalidated_Redirects_and_Forwards_Cheat_Sheet.md) the only valid redirect URLs are the ones from domains you have set when adding your platforms in the console interface.
 
-
         Parameters
         ----------
         user_id : str
@@ -848,7 +838,6 @@ class Account(Service):
         
         A user is limited to 10 active sessions at a time by default. [Learn more about session limits](https://appwrite.io/docs/authentication-security#limits).
 
-
         Parameters
         ----------
         email : str
@@ -883,11 +872,13 @@ class Account(Service):
             'content-type': 'application/json',
         }, api_params)
 
+    @deprecated("This API has been deprecated since 1.6.0. Please use `account.create_session` instead.")
     def update_magic_url_session(self, user_id: str, secret: str) -> Dict[str, Any]:
         """
         Use this endpoint to create a session from token. Provide the **userId** and **secret** parameters from the successful response of authentication flows initiated by token creation. For example, magic URL and phone login.
 
-
+        .. deprecated::1.6.0
+            This API has been deprecated since 1.6.0. Please use `account.create_session` instead.
         Parameters
         ----------
         user_id : str
@@ -922,11 +913,13 @@ class Account(Service):
             'content-type': 'application/json',
         }, api_params)
 
+    @deprecated("This API has been deprecated since 1.6.0. Please use `account.create_session` instead.")
     def update_phone_session(self, user_id: str, secret: str) -> Dict[str, Any]:
         """
         Use this endpoint to create a session from token. Provide the **userId** and **secret** parameters from the successful response of authentication flows initiated by token creation. For example, magic URL and phone login.
 
-
+        .. deprecated::1.6.0
+            This API has been deprecated since 1.6.0. Please use `account.create_session` instead.
         Parameters
         ----------
         user_id : str
@@ -965,7 +958,6 @@ class Account(Service):
         """
         Use this endpoint to create a session from token. Provide the **userId** and **secret** parameters from the successful response of authentication flows initiated by token creation. For example, magic URL and phone login.
 
-
         Parameters
         ----------
         user_id : str
@@ -1004,7 +996,6 @@ class Account(Service):
         """
         Use this endpoint to get a logged in user's session using a Session ID. Inputting 'current' will return the current session being used.
 
-
         Parameters
         ----------
         session_id : str
@@ -1036,7 +1027,6 @@ class Account(Service):
         """
         Use this endpoint to extend a session's length. Extending a session is useful when session expiry is short. If the session was created using an OAuth provider, this endpoint refreshes the access token from the provider.
 
-
         Parameters
         ----------
         session_id : str
@@ -1069,7 +1059,6 @@ class Account(Service):
         """
         Logout the user. Use 'current' as the session ID to logout on this device, use a session ID to logout on another device. If you're looking to logout the user on all devices, use [Delete Sessions](https://appwrite.io/docs/references/cloud/client-web/account#deleteSessions) instead.
 
-
         Parameters
         ----------
         session_id : str
@@ -1120,20 +1109,20 @@ class Account(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def create_email_token(self, user_id: str, email: str, phrase: bool = None) -> Dict[str, Any]:
+    def create_email_token(self, user_id: str, email: str, phrase: Optional[bool] = None) -> Dict[str, Any]:
         """
-        Sends the user an email with a secret key for creating a session. If the provided user ID has not be registered, a new user will be created. Use the returned user ID and secret and submit a request to the [POST /v1/account/sessions/token](https://appwrite.io/docs/references/cloud/client-web/account#createSession) endpoint to complete the login process. The secret sent to the user's email is valid for 15 minutes.
+        Sends the user an email with a secret key for creating a session. If the email address has never been used, a **new account is created** using the provided `userId`. Otherwise, if the email address is already attached to an account, the **user ID is ignored**. Then, the user will receive an email with the one-time password. Use the returned user ID and secret and submit a request to the [POST /v1/account/sessions/token](https://appwrite.io/docs/references/cloud/client-web/account#createSession) endpoint to complete the login process. The secret sent to the user's email is valid for 15 minutes.
         
         A user is limited to 10 active sessions at a time by default. [Learn more about session limits](https://appwrite.io/docs/authentication-security#limits).
-
+        
 
         Parameters
         ----------
         user_id : str
-            User ID. Choose a custom ID or generate a random ID with `ID.unique()`. Valid chars are a-z, A-Z, 0-9, period, hyphen, and underscore. Can't start with a special char. Max length is 36 chars.
+            User ID. Choose a custom ID or generate a random ID with `ID.unique()`. Valid chars are a-z, A-Z, 0-9, period, hyphen, and underscore. Can't start with a special char. Max length is 36 chars. If the email address has never been used, a new account is created using the provided userId. Otherwise, if the email address is already attached to an account, the user ID is ignored.
         email : str
             User email.
-        phrase : bool
+        phrase : Optional[bool]
             Toggle for security phrase. If enabled, email will be send with a randomly generated phrase and the phrase will also be included in the response. Confirming phrases match increases the security of your authentication flow.
         
         Returns
@@ -1164,23 +1153,22 @@ class Account(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def create_magic_url_token(self, user_id: str, email: str, url: str = None, phrase: bool = None) -> Dict[str, Any]:
+    def create_magic_url_token(self, user_id: str, email: str, url: Optional[str] = None, phrase: Optional[bool] = None) -> Dict[str, Any]:
         """
         Sends the user an email with a secret key for creating a session. If the provided user ID has not been registered, a new user will be created. When the user clicks the link in the email, the user is redirected back to the URL you provided with the secret key and userId values attached to the URL query string. Use the query string parameters to submit a request to the [POST /v1/account/sessions/token](https://appwrite.io/docs/references/cloud/client-web/account#createSession) endpoint to complete the login process. The link sent to the user's email address is valid for 1 hour.
         
         A user is limited to 10 active sessions at a time by default. [Learn more about session limits](https://appwrite.io/docs/authentication-security#limits).
         
 
-
         Parameters
         ----------
         user_id : str
-            Unique Id. Choose a custom ID or generate a random ID with `ID.unique()`. Valid chars are a-z, A-Z, 0-9, period, hyphen, and underscore. Can't start with a special char. Max length is 36 chars.
+            Unique Id. Choose a custom ID or generate a random ID with `ID.unique()`. Valid chars are a-z, A-Z, 0-9, period, hyphen, and underscore. Can't start with a special char. Max length is 36 chars. If the email address has never been used, a new account is created using the provided userId. Otherwise, if the email address is already attached to an account, the user ID is ignored.
         email : str
             User email.
-        url : str
+        url : Optional[str]
             URL to redirect the user back to your app from the magic URL login. Only URLs from hostnames in your project platform list are allowed. This requirement helps to prevent an [open redirect](https://cheatsheetseries.owasp.org/cheatsheets/Unvalidated_Redirects_and_Forwards_Cheat_Sheet.html) attack against your project API.
-        phrase : bool
+        phrase : Optional[bool]
             Toggle for security phrase. If enabled, email will be send with a randomly generated phrase and the phrase will also be included in the response. Confirming phrases match increases the security of your authentication flow.
         
         Returns
@@ -1212,7 +1200,7 @@ class Account(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def create_o_auth2_token(self, provider: OAuthProvider, success: str = None, failure: str = None, scopes: List[str] = None) -> str:
+    def create_o_auth2_token(self, provider: OAuthProvider, success: Optional[str] = None, failure: Optional[str] = None, scopes: Optional[List[str]] = None) -> str:
         """
         Allow the user to login to their account using the OAuth2 provider of their choice. Each OAuth2 provider should be enabled from the Appwrite console first. Use the success and failure arguments to provide a redirect URL's back to your app when login is completed. 
         
@@ -1220,16 +1208,15 @@ class Account(Service):
         
         A user is limited to 10 active sessions at a time by default. [Learn more about session limits](https://appwrite.io/docs/authentication-security#limits).
 
-
         Parameters
         ----------
         provider : OAuthProvider
             OAuth2 Provider. Currently, supported providers are: amazon, apple, auth0, authentik, autodesk, bitbucket, bitly, box, dailymotion, discord, disqus, dropbox, etsy, facebook, figma, github, gitlab, google, linkedin, microsoft, notion, oidc, okta, paypal, paypalSandbox, podio, salesforce, slack, spotify, stripe, tradeshift, tradeshiftBox, twitch, wordpress, yahoo, yammer, yandex, zoho, zoom.
-        success : str
+        success : Optional[str]
             URL to redirect back to your app after a successful login attempt.  Only URLs from hostnames in your project's platform list are allowed. This requirement helps to prevent an [open redirect](https://cheatsheetseries.owasp.org/cheatsheets/Unvalidated_Redirects_and_Forwards_Cheat_Sheet.html) attack against your project API.
-        failure : str
+        failure : Optional[str]
             URL to redirect back to your app after a failed login attempt.  Only URLs from hostnames in your project's platform list are allowed. This requirement helps to prevent an [open redirect](https://cheatsheetseries.owasp.org/cheatsheets/Unvalidated_Redirects_and_Forwards_Cheat_Sheet.html) attack against your project API.
-        scopes : List[str]
+        scopes : Optional[List[str]]
             A list of custom OAuth2 scopes. Check each provider internal docs for a list of supported scopes. Maximum of 100 scopes are allowed, each 4096 characters long.
         
         Returns
@@ -1263,11 +1250,10 @@ class Account(Service):
         
         A user is limited to 10 active sessions at a time by default. [Learn more about session limits](https://appwrite.io/docs/authentication-security#limits).
 
-
         Parameters
         ----------
         user_id : str
-            Unique Id. Choose a custom ID or generate a random ID with `ID.unique()`. Valid chars are a-z, A-Z, 0-9, period, hyphen, and underscore. Can't start with a special char. Max length is 36 chars.
+            Unique Id. Choose a custom ID or generate a random ID with `ID.unique()`. Valid chars are a-z, A-Z, 0-9, period, hyphen, and underscore. Can't start with a special char. Max length is 36 chars. If the phone number has never been used, a new account is created using the provided userId. Otherwise, if the phone number is already attached to an account, the user ID is ignored.
         phone : str
             Phone number. Format this number with a leading '+' and a country code, e.g., +16175551212.
         
@@ -1298,14 +1284,13 @@ class Account(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def create_verification(self, url: str) -> Dict[str, Any]:
+    def create_email_verification(self, url: str) -> Dict[str, Any]:
         """
         Use this endpoint to send a verification message to your user email address to confirm they are the valid owners of that address. Both the **userId** and **secret** arguments will be passed as query parameters to the URL you have provided to be attached to the verification email. The provided URL should redirect the user back to your app and allow you to complete the verification process by verifying both the **userId** and **secret** parameters. Learn more about how to [complete the verification process](https://appwrite.io/docs/references/cloud/client-web/account#updateVerification). The verification link sent to the user's email address is valid for 7 days.
         
         Please note that in order to avoid a [Redirect Attack](https://github.com/OWASP/CheatSheetSeries/blob/master/cheatsheets/Unvalidated_Redirects_and_Forwards_Cheat_Sheet.md), the only valid redirect URLs are the ones from domains you have set when adding your platforms in the console interface.
         
 
-
         Parameters
         ----------
         url : str
@@ -1322,7 +1307,7 @@ class Account(Service):
             If API request fails
         """
 
-        api_path = '/account/verification'
+        api_path = '/account/verifications/email'
         api_params = {}
         if url is None:
             raise AppwriteException('Missing required parameter: "url"')
@@ -1334,11 +1319,48 @@ class Account(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def update_verification(self, user_id: str, secret: str) -> Dict[str, Any]:
+    @deprecated("This API has been deprecated since 1.8.0. Please use `account.create_email_verification` instead.")
+    def create_verification(self, url: str) -> Dict[str, Any]:
+        """
+        Use this endpoint to send a verification message to your user email address to confirm they are the valid owners of that address. Both the **userId** and **secret** arguments will be passed as query parameters to the URL you have provided to be attached to the verification email. The provided URL should redirect the user back to your app and allow you to complete the verification process by verifying both the **userId** and **secret** parameters. Learn more about how to [complete the verification process](https://appwrite.io/docs/references/cloud/client-web/account#updateVerification). The verification link sent to the user's email address is valid for 7 days.
+        
+        Please note that in order to avoid a [Redirect Attack](https://github.com/OWASP/CheatSheetSeries/blob/master/cheatsheets/Unvalidated_Redirects_and_Forwards_Cheat_Sheet.md), the only valid redirect URLs are the ones from domains you have set when adding your platforms in the console interface.
+        
+
+        .. deprecated::1.8.0
+            This API has been deprecated since 1.8.0. Please use `account.create_email_verification` instead.
+        Parameters
+        ----------
+        url : str
+            URL to redirect the user back to your app from the verification email. Only URLs from hostnames in your project platform list are allowed. This requirement helps to prevent an [open redirect](https://cheatsheetseries.owasp.org/cheatsheets/Unvalidated_Redirects_and_Forwards_Cheat_Sheet.html) attack against your project API.
+        
+        Returns
+        -------
+        Dict[str, Any]
+            API response as a dictionary
+        
+        Raises
+        ------
+        AppwriteException
+            If API request fails
+        """
+
+        api_path = '/account/verifications/email'
+        api_params = {}
+        if url is None:
+            raise AppwriteException('Missing required parameter: "url"')
+
+
+        api_params['url'] = url
+
+        return self.client.call('post', api_path, {
+            'content-type': 'application/json',
+        }, api_params)
+
+    def update_email_verification(self, user_id: str, secret: str) -> Dict[str, Any]:
         """
         Use this endpoint to complete the user email verification process. Use both the **userId** and **secret** parameters that were attached to your app URL to verify the user email ownership. If confirmed this route will return a 200 status code.
 
-
         Parameters
         ----------
         user_id : str
@@ -1357,7 +1379,48 @@ class Account(Service):
             If API request fails
         """
 
-        api_path = '/account/verification'
+        api_path = '/account/verifications/email'
+        api_params = {}
+        if user_id is None:
+            raise AppwriteException('Missing required parameter: "user_id"')
+
+        if secret is None:
+            raise AppwriteException('Missing required parameter: "secret"')
+
+
+        api_params['userId'] = user_id
+        api_params['secret'] = secret
+
+        return self.client.call('put', api_path, {
+            'content-type': 'application/json',
+        }, api_params)
+
+    @deprecated("This API has been deprecated since 1.8.0. Please use `account.update_email_verification` instead.")
+    def update_verification(self, user_id: str, secret: str) -> Dict[str, Any]:
+        """
+        Use this endpoint to complete the user email verification process. Use both the **userId** and **secret** parameters that were attached to your app URL to verify the user email ownership. If confirmed this route will return a 200 status code.
+
+        .. deprecated::1.8.0
+            This API has been deprecated since 1.8.0. Please use `account.update_email_verification` instead.
+        Parameters
+        ----------
+        user_id : str
+            User ID.
+        secret : str
+            Valid verification token.
+        
+        Returns
+        -------
+        Dict[str, Any]
+            API response as a dictionary
+        
+        Raises
+        ------
+        AppwriteException
+            If API request fails
+        """
+
+        api_path = '/account/verifications/email'
         api_params = {}
         if user_id is None:
             raise AppwriteException('Missing required parameter: "user_id"')
@@ -1388,7 +1451,7 @@ class Account(Service):
             If API request fails
         """
 
-        api_path = '/account/verification/phone'
+        api_path = '/account/verifications/phone'
         api_params = {}
 
         return self.client.call('post', api_path, {
@@ -1399,7 +1462,6 @@ class Account(Service):
         """
         Use this endpoint to complete the user phone verification process. Use the **userId** and **secret** that were sent to your user's phone number to verify the user email ownership. If confirmed this route will return a 200 status code.
 
-
         Parameters
         ----------
         user_id : str
@@ -1418,7 +1480,7 @@ class Account(Service):
             If API request fails
         """
 
-        api_path = '/account/verification/phone'
+        api_path = '/account/verifications/phone'
         api_params = {}
         if user_id is None:
             raise AppwriteException('Missing required parameter: "user_id"')
