@@ -1,6 +1,7 @@
 from ..service import Service
-from typing import List, Dict, Any
+from typing import List, Dict, Any, Optional
 from ..exception import AppwriteException
+from appwrite.utils.deprecated import deprecated
 from ..enums.browser import Browser;
 from ..enums.credit_card import CreditCard;
 from ..enums.flag import Flag;
@@ -10,22 +11,21 @@ class Avatars(Service):
     def __init__(self, client) -> None:
         super(Avatars, self).__init__(client)
 
-    def get_browser(self, code: Browser, width: float = None, height: float = None, quality: float = None) -> bytes:
+    def get_browser(self, code: Browser, width: Optional[float] = None, height: Optional[float] = None, quality: Optional[float] = None) -> bytes:
         """
         You can use this endpoint to show different browser icons to your users. The code argument receives the browser code as it appears in your user [GET /account/sessions](https://appwrite.io/docs/references/cloud/client-web/account#getSessions) endpoint. Use width, height and quality arguments to change the output settings.
         
         When one dimension is specified and the other is 0, the image is scaled with preserved aspect ratio. If both dimensions are 0, the API provides an image at source quality. If dimensions are not specified, the default size of image returned is 100x100px.
 
-
         Parameters
         ----------
         code : Browser
             Browser Code.
-        width : float
+        width : Optional[float]
             Image width. Pass an integer between 0 to 2000. Defaults to 100.
-        height : float
+        height : Optional[float]
             Image height. Pass an integer between 0 to 2000. Defaults to 100.
-        quality : float
+        quality : Optional[float]
             Image quality. Pass an integer between 0 to 100. Defaults to keep existing image quality.
         
         Returns
@@ -53,23 +53,22 @@ class Avatars(Service):
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def get_credit_card(self, code: CreditCard, width: float = None, height: float = None, quality: float = None) -> bytes:
+    def get_credit_card(self, code: CreditCard, width: Optional[float] = None, height: Optional[float] = None, quality: Optional[float] = None) -> bytes:
         """
         The credit card endpoint will return you the icon of the credit card provider you need. Use width, height and quality arguments to change the output settings.
         
         When one dimension is specified and the other is 0, the image is scaled with preserved aspect ratio. If both dimensions are 0, the API provides an image at source quality. If dimensions are not specified, the default size of image returned is 100x100px.
         
 
-
         Parameters
         ----------
         code : CreditCard
-            Credit Card Code. Possible values: amex, argencard, cabal, cencosud, diners, discover, elo, hipercard, jcb, mastercard, naranja, targeta-shopping, union-china-pay, visa, mir, maestro, rupay.
-        width : float
+            Credit Card Code. Possible values: amex, argencard, cabal, cencosud, diners, discover, elo, hipercard, jcb, mastercard, naranja, targeta-shopping, unionpay, visa, mir, maestro, rupay.
+        width : Optional[float]
             Image width. Pass an integer between 0 to 2000. Defaults to 100.
-        height : float
+        height : Optional[float]
             Image height. Pass an integer between 0 to 2000. Defaults to 100.
-        quality : float
+        quality : Optional[float]
             Image quality. Pass an integer between 0 to 100. Defaults to keep existing image quality.
         
         Returns
@@ -103,7 +102,6 @@ class Avatars(Service):
         
         This endpoint does not follow HTTP redirects.
 
-
         Parameters
         ----------
         url : str
@@ -131,23 +129,22 @@ class Avatars(Service):
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def get_flag(self, code: Flag, width: float = None, height: float = None, quality: float = None) -> bytes:
+    def get_flag(self, code: Flag, width: Optional[float] = None, height: Optional[float] = None, quality: Optional[float] = None) -> bytes:
         """
         You can use this endpoint to show different country flags icons to your users. The code argument receives the 2 letter country code. Use width, height and quality arguments to change the output settings. Country codes follow the [ISO 3166-1](https://en.wikipedia.org/wiki/ISO_3166-1) standard.
         
         When one dimension is specified and the other is 0, the image is scaled with preserved aspect ratio. If both dimensions are 0, the API provides an image at source quality. If dimensions are not specified, the default size of image returned is 100x100px.
         
 
-
         Parameters
         ----------
         code : Flag
             Country Code. ISO Alpha-2 country code format.
-        width : float
+        width : Optional[float]
             Image width. Pass an integer between 0 to 2000. Defaults to 100.
-        height : float
+        height : Optional[float]
             Image height. Pass an integer between 0 to 2000. Defaults to 100.
-        quality : float
+        quality : Optional[float]
             Image quality. Pass an integer between 0 to 100. Defaults to keep existing image quality.
         
         Returns
@@ -175,7 +172,7 @@ class Avatars(Service):
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def get_image(self, url: str, width: float = None, height: float = None) -> bytes:
+    def get_image(self, url: str, width: Optional[float] = None, height: Optional[float] = None) -> bytes:
         """
         Use this endpoint to fetch a remote image URL and crop it to any image size you want. This endpoint is very useful if you need to crop and display remote images in your app or in case you want to make sure a 3rd party image is properly served using a TLS protocol.
         
@@ -183,14 +180,13 @@ class Avatars(Service):
         
         This endpoint does not follow HTTP redirects.
 
-
         Parameters
         ----------
         url : str
             Image URL which you want to crop.
-        width : float
+        width : Optional[float]
             Resize preview image width, Pass an integer between 0 to 2000. Defaults to 400.
-        height : float
+        height : Optional[float]
             Resize preview image height, Pass an integer between 0 to 2000. Defaults to 400.
         
         Returns
@@ -217,7 +213,7 @@ class Avatars(Service):
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def get_initials(self, name: str = None, width: float = None, height: float = None, background: str = None) -> bytes:
+    def get_initials(self, name: Optional[str] = None, width: Optional[float] = None, height: Optional[float] = None, background: Optional[str] = None) -> bytes:
         """
         Use this endpoint to show your user initials avatar icon on your website or app. By default, this route will try to print your logged-in user name or email initials. You can also overwrite the user name if you pass the 'name' parameter. If no name is given and no user is logged, an empty avatar will be returned.
         
@@ -226,16 +222,15 @@ class Avatars(Service):
         When one dimension is specified and the other is 0, the image is scaled with preserved aspect ratio. If both dimensions are 0, the API provides an image at source quality. If dimensions are not specified, the default size of image returned is 100x100px.
         
 
-
         Parameters
         ----------
-        name : str
+        name : Optional[str]
             Full Name. When empty, current user name or email will be used. Max length: 128 chars.
-        width : float
+        width : Optional[float]
             Image width. Pass an integer between 0 to 2000. Defaults to 100.
-        height : float
+        height : Optional[float]
             Image height. Pass an integer between 0 to 2000. Defaults to 100.
-        background : str
+        background : Optional[str]
             Changes background color. By default a random color will be picked and stay will persistent to the given name.
         
         Returns
@@ -260,21 +255,20 @@ class Avatars(Service):
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def get_qr(self, text: str, size: float = None, margin: float = None, download: bool = None) -> bytes:
+    def get_qr(self, text: str, size: Optional[float] = None, margin: Optional[float] = None, download: Optional[bool] = None) -> bytes:
         """
         Converts a given plain text to a QR code image. You can use the query parameters to change the size and style of the resulting image.
         
 
-
         Parameters
         ----------
         text : str
             Plain text to be converted to QR code image.
-        size : float
+        size : Optional[float]
             QR code size. Pass an integer between 1 to 1000. Defaults to 400.
-        margin : float
+        margin : Optional[float]
             Margin from edge. Pass an integer between 0 to 10. Defaults to 1.
-        download : bool
+        download : Optional[bool]
             Return resulting image with 'Content-Disposition: attachment ' headers for the browser to start downloading it. Pass 0 for no header, or 1 for otherwise. Default value is set to 0.
         
         Returns
