@@ -1,6 +1,7 @@
 from ..service import Service
-from typing import List, Dict, Any
+from typing import List, Dict, Any, Optional
 from ..exception import AppwriteException
+from appwrite.utils.deprecated import deprecated
 from ..enums.compression import Compression;
 from ..input_file import InputFile
 from ..enums.image_gravity import ImageGravity;
@@ -11,17 +12,18 @@ class Storage(Service):
     def __init__(self, client) -> None:
         super(Storage, self).__init__(client)
 
-    def list_buckets(self, queries: List[str] = None, search: str = None) -> Dict[str, Any]:
+    def list_buckets(self, queries: Optional[List[str]] = None, search: Optional[str] = None, total: Optional[bool] = None) -> Dict[str, Any]:
         """
         Get a list of all the storage buckets. You can use the query params to filter your results.
 
-
         Parameters
         ----------
-        queries : List[str]
+        queries : Optional[List[str]]
             Array of query strings generated using the Query class provided by the SDK. [Learn more about queries](https://appwrite.io/docs/queries). Maximum of 100 queries are allowed, each 4096 characters long. You may filter on the following attributes: enabled, name, fileSecurity, maximumFileSize, encryption, antivirus
-        search : str
+        search : Optional[str]
             Search term to filter your list results. Max length: 256 chars.
+        total : Optional[bool]
+            When set to false, the total count returned will be 0 and will not be calculated.
         
         Returns
         -------
@@ -39,36 +41,36 @@ class Storage(Service):
 
         api_params['queries'] = queries
         api_params['search'] = search
+        api_params['total'] = total
 
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def create_bucket(self, bucket_id: str, name: str, permissions: List[str] = None, file_security: bool = None, enabled: bool = None, maximum_file_size: float = None, allowed_file_extensions: List[str] = None, compression: Compression = None, encryption: bool = None, antivirus: bool = None) -> Dict[str, Any]:
+    def create_bucket(self, bucket_id: str, name: str, permissions: Optional[List[str]] = None, file_security: Optional[bool] = None, enabled: Optional[bool] = None, maximum_file_size: Optional[float] = None, allowed_file_extensions: Optional[List[str]] = None, compression: Optional[Compression] = None, encryption: Optional[bool] = None, antivirus: Optional[bool] = None) -> Dict[str, Any]:
         """
         Create a new storage bucket.
 
-
         Parameters
         ----------
         bucket_id : str
             Unique Id. Choose a custom ID or generate a random ID with `ID.unique()`. Valid chars are a-z, A-Z, 0-9, period, hyphen, and underscore. Can't start with a special char. Max length is 36 chars.
         name : str
             Bucket name
-        permissions : List[str]
+        permissions : Optional[List[str]]
             An array of permission strings. By default, no user is granted with any permissions. [Learn more about permissions](https://appwrite.io/docs/permissions).
-        file_security : bool
+        file_security : Optional[bool]
             Enables configuring permissions for individual file. A user needs one of file or bucket level permissions to access a file. [Learn more about permissions](https://appwrite.io/docs/permissions).
-        enabled : bool
+        enabled : Optional[bool]
             Is bucket enabled? When set to 'disabled', users cannot access the files in this bucket but Server SDKs with and API key can still access the bucket. No files are lost when this is toggled.
-        maximum_file_size : float
+        maximum_file_size : Optional[float]
             Maximum file size allowed in bytes. Maximum allowed value is 30MB.
-        allowed_file_extensions : List[str]
+        allowed_file_extensions : Optional[List[str]]
             Allowed file extensions. Maximum of 100 extensions are allowed, each 64 characters long.
-        compression : Compression
+        compression : Optional[Compression]
             Compression algorithm choosen for compression. Can be one of none,  [gzip](https://en.wikipedia.org/wiki/Gzip), or [zstd](https://en.wikipedia.org/wiki/Zstd), For file size above 20MB compression is skipped even if it's enabled
-        encryption : bool
+        encryption : Optional[bool]
             Is encryption enabled? For file size above 20MB encryption is skipped even if it's enabled
-        antivirus : bool
+        antivirus : Optional[bool]
             Is virus scanning enabled? For file size above 20MB AntiVirus scanning is skipped even if it's enabled
         
         Returns
@@ -110,7 +112,6 @@ class Storage(Service):
         """
         Get a storage bucket by its unique ID. This endpoint response returns a JSON object with the storage bucket metadata.
 
-
         Parameters
         ----------
         bucket_id : str
@@ -138,32 +139,31 @@ class Storage(Service):
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def update_bucket(self, bucket_id: str, name: str, permissions: List[str] = None, file_security: bool = None, enabled: bool = None, maximum_file_size: float = None, allowed_file_extensions: List[str] = None, compression: Compression = None, encryption: bool = None, antivirus: bool = None) -> Dict[str, Any]:
+    def update_bucket(self, bucket_id: str, name: str, permissions: Optional[List[str]] = None, file_security: Optional[bool] = None, enabled: Optional[bool] = None, maximum_file_size: Optional[float] = None, allowed_file_extensions: Optional[List[str]] = None, compression: Optional[Compression] = None, encryption: Optional[bool] = None, antivirus: Optional[bool] = None) -> Dict[str, Any]:
         """
         Update a storage bucket by its unique ID.
 
-
         Parameters
         ----------
         bucket_id : str
             Bucket unique ID.
         name : str
             Bucket name
-        permissions : List[str]
+        permissions : Optional[List[str]]
             An array of permission strings. By default, the current permissions are inherited. [Learn more about permissions](https://appwrite.io/docs/permissions).
-        file_security : bool
+        file_security : Optional[bool]
             Enables configuring permissions for individual file. A user needs one of file or bucket level permissions to access a file. [Learn more about permissions](https://appwrite.io/docs/permissions).
-        enabled : bool
+        enabled : Optional[bool]
             Is bucket enabled? When set to 'disabled', users cannot access the files in this bucket but Server SDKs with and API key can still access the bucket. No files are lost when this is toggled.
-        maximum_file_size : float
+        maximum_file_size : Optional[float]
             Maximum file size allowed in bytes. Maximum allowed value is 30MB.
-        allowed_file_extensions : List[str]
+        allowed_file_extensions : Optional[List[str]]
             Allowed file extensions. Maximum of 100 extensions are allowed, each 64 characters long.
-        compression : Compression
+        compression : Optional[Compression]
             Compression algorithm choosen for compression. Can be one of none, [gzip](https://en.wikipedia.org/wiki/Gzip), or [zstd](https://en.wikipedia.org/wiki/Zstd), For file size above 20MB compression is skipped even if it's enabled
-        encryption : bool
+        encryption : Optional[bool]
             Is encryption enabled? For file size above 20MB encryption is skipped even if it's enabled
-        antivirus : bool
+        antivirus : Optional[bool]
             Is virus scanning enabled? For file size above 20MB AntiVirus scanning is skipped even if it's enabled
         
         Returns
@@ -205,7 +205,6 @@ class Storage(Service):
         """
         Delete a storage bucket by its unique ID.
 
-
         Parameters
         ----------
         bucket_id : str
@@ -234,19 +233,20 @@ class Storage(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def list_files(self, bucket_id: str, queries: List[str] = None, search: str = None) -> Dict[str, Any]:
+    def list_files(self, bucket_id: str, queries: Optional[List[str]] = None, search: Optional[str] = None, total: Optional[bool] = None) -> Dict[str, Any]:
         """
         Get a list of all the user files. You can use the query params to filter your results.
 
-
         Parameters
         ----------
         bucket_id : str
             Storage bucket unique ID. You can create a new storage bucket using the Storage service [server integration](https://appwrite.io/docs/server/storage#createBucket).
-        queries : List[str]
+        queries : Optional[List[str]]
             Array of query strings generated using the Query class provided by the SDK. [Learn more about queries](https://appwrite.io/docs/queries). Maximum of 100 queries are allowed, each 4096 characters long. You may filter on the following attributes: name, signature, mimeType, sizeOriginal, chunksTotal, chunksUploaded
-        search : str
+        search : Optional[str]
             Search term to filter your list results. Max length: 256 chars.
+        total : Optional[bool]
+            When set to false, the total count returned will be 0 and will not be calculated.
         
         Returns
         -------
@@ -268,11 +268,12 @@ class Storage(Service):
 
         api_params['queries'] = queries
         api_params['search'] = search
+        api_params['total'] = total
 
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def create_file(self, bucket_id: str, file_id: str, file: InputFile, permissions: List[str] = None, on_progress = None) -> Dict[str, Any]:
+    def create_file(self, bucket_id: str, file_id: str, file: InputFile, permissions: Optional[List[str]] = None, on_progress = None) -> Dict[str, Any]:
         """
         Create a new file. Before using this route, you should create a new bucket resource using either a [server integration](https://appwrite.io/docs/server/storage#storageCreateBucket) API or directly from your Appwrite console.
         
@@ -283,7 +284,6 @@ class Storage(Service):
         If you're creating a new file using one of the Appwrite SDKs, all the chunking logic will be managed by the SDK internally.
         
 
-
         Parameters
         ----------
         bucket_id : str
@@ -292,7 +292,7 @@ class Storage(Service):
             File ID. Choose a custom ID or generate a random ID with `ID.unique()`. Valid chars are a-z, A-Z, 0-9, period, hyphen, and underscore. Can't start with a special char. Max length is 36 chars.
         file : InputFile
             Binary file. Appwrite SDKs provide helpers to handle file input. [Learn about file input](https://appwrite.io/docs/products/storage/upload-download#input-file).
-        permissions : List[str]
+        permissions : Optional[List[str]]
             An array of permission strings. By default, only the current user is granted all permissions. [Learn more about permissions](https://appwrite.io/docs/permissions).
                 on_progress : callable, optional
             Optional callback for upload progress
@@ -339,7 +339,6 @@ class Storage(Service):
         """
         Get a file by its unique ID. This endpoint response returns a JSON object with the file metadata.
 
-
         Parameters
         ----------
         bucket_id : str
@@ -373,20 +372,19 @@ class Storage(Service):
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def update_file(self, bucket_id: str, file_id: str, name: str = None, permissions: List[str] = None) -> Dict[str, Any]:
+    def update_file(self, bucket_id: str, file_id: str, name: Optional[str] = None, permissions: Optional[List[str]] = None) -> Dict[str, Any]:
         """
         Update a file by its unique ID. Only users with write permissions have access to update this resource.
 
-
         Parameters
         ----------
         bucket_id : str
             Storage bucket unique ID. You can create a new storage bucket using the Storage service [server integration](https://appwrite.io/docs/server/storage#createBucket).
         file_id : str
             File unique ID.
-        name : str
+        name : Optional[str]
             Name of the file
-        permissions : List[str]
+        permissions : Optional[List[str]]
             An array of permission string. By default, the current permissions are inherited. [Learn more about permissions](https://appwrite.io/docs/permissions).
         
         Returns
@@ -422,7 +420,6 @@ class Storage(Service):
         """
         Delete a file by its unique ID. Only users with write permissions have access to delete this resource.
 
-
         Parameters
         ----------
         bucket_id : str
@@ -457,18 +454,17 @@ class Storage(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def get_file_download(self, bucket_id: str, file_id: str, token: str = None) -> bytes:
+    def get_file_download(self, bucket_id: str, file_id: str, token: Optional[str] = None) -> bytes:
         """
         Get a file content by its unique ID. The endpoint response return with a 'Content-Disposition: attachment' header that tells the browser to start downloading the file to user downloads directory.
 
-
         Parameters
         ----------
         bucket_id : str
             Storage bucket ID. You can create a new storage bucket using the Storage service [server integration](https://appwrite.io/docs/server/storage#createBucket).
         file_id : str
             File ID.
-        token : str
+        token : Optional[str]
             File token for accessing this file.
         
         Returns
@@ -498,40 +494,39 @@ class Storage(Service):
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def get_file_preview(self, bucket_id: str, file_id: str, width: float = None, height: float = None, gravity: ImageGravity = None, quality: float = None, border_width: float = None, border_color: str = None, border_radius: float = None, opacity: float = None, rotation: float = None, background: str = None, output: ImageFormat = None, token: str = None) -> bytes:
+    def get_file_preview(self, bucket_id: str, file_id: str, width: Optional[float] = None, height: Optional[float] = None, gravity: Optional[ImageGravity] = None, quality: Optional[float] = None, border_width: Optional[float] = None, border_color: Optional[str] = None, border_radius: Optional[float] = None, opacity: Optional[float] = None, rotation: Optional[float] = None, background: Optional[str] = None, output: Optional[ImageFormat] = None, token: Optional[str] = None) -> bytes:
         """
         Get a file preview image. Currently, this method supports preview for image files (jpg, png, and gif), other supported formats, like pdf, docs, slides, and spreadsheets, will return the file icon image. You can also pass query string arguments for cutting and resizing your preview image. Preview is supported only for image files smaller than 10MB.
 
-
         Parameters
         ----------
         bucket_id : str
             Storage bucket unique ID. You can create a new storage bucket using the Storage service [server integration](https://appwrite.io/docs/server/storage#createBucket).
         file_id : str
             File ID
-        width : float
+        width : Optional[float]
             Resize preview image width, Pass an integer between 0 to 4000.
-        height : float
+        height : Optional[float]
             Resize preview image height, Pass an integer between 0 to 4000.
-        gravity : ImageGravity
+        gravity : Optional[ImageGravity]
             Image crop gravity. Can be one of center,top-left,top,top-right,left,right,bottom-left,bottom,bottom-right
-        quality : float
+        quality : Optional[float]
             Preview image quality. Pass an integer between 0 to 100. Defaults to keep existing image quality.
-        border_width : float
+        border_width : Optional[float]
             Preview image border in pixels. Pass an integer between 0 to 100. Defaults to 0.
-        border_color : str
+        border_color : Optional[str]
             Preview image border color. Use a valid HEX color, no # is needed for prefix.
-        border_radius : float
+        border_radius : Optional[float]
             Preview image border radius in pixels. Pass an integer between 0 to 4000.
-        opacity : float
+        opacity : Optional[float]
             Preview image opacity. Only works with images having an alpha channel (like png). Pass a number between 0 to 1.
-        rotation : float
+        rotation : Optional[float]
             Preview image rotation in degrees. Pass an integer between -360 and 360.
-        background : str
+        background : Optional[str]
             Preview image background color. Only works with transparent images (png). Use a valid HEX color, no # is needed for prefix.
-        output : ImageFormat
+        output : Optional[ImageFormat]
             Output format type (jpeg, jpg, png, gif and webp).
-        token : str
+        token : Optional[str]
             File token for accessing this file.
         
         Returns
@@ -572,18 +567,17 @@ class Storage(Service):
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def get_file_view(self, bucket_id: str, file_id: str, token: str = None) -> bytes:
+    def get_file_view(self, bucket_id: str, file_id: str, token: Optional[str] = None) -> bytes:
         """
         Get a file content by its unique ID. This endpoint is similar to the download method but returns with no  'Content-Disposition: attachment' header.
 
-
         Parameters
         ----------
         bucket_id : str
             Storage bucket unique ID. You can create a new storage bucket using the Storage service [server integration](https://appwrite.io/docs/server/storage#createBucket).
         file_id : str
             File ID.
-        token : str
+        token : Optional[str]
             File token for accessing this file.
         
         Returns
