@@ -1,6 +1,7 @@
 from ..service import Service
-from typing import List, Dict, Any
+from typing import List, Dict, Any, Optional
 from ..exception import AppwriteException
+from appwrite.utils.deprecated import deprecated
 from ..enums.password_hash import PasswordHash;
 from ..enums.authenticator_type import AuthenticatorType;
 from ..enums.messaging_provider_type import MessagingProviderType;
@@ -10,17 +11,18 @@ class Users(Service):
     def __init__(self, client) -> None:
         super(Users, self).__init__(client)
 
-    def list(self, queries: List[str] = None, search: str = None) -> Dict[str, Any]:
+    def list(self, queries: Optional[List[str]] = None, search: Optional[str] = None, total: Optional[bool] = None) -> Dict[str, Any]:
         """
         Get a list of all the project's users. You can use the query params to filter your results.
 
-
         Parameters
         ----------
-        queries : List[str]
+        queries : Optional[List[str]]
             Array of query strings generated using the Query class provided by the SDK. [Learn more about queries](https://appwrite.io/docs/queries). Maximum of 100 queries are allowed, each 4096 characters long. You may filter on the following attributes: name, email, phone, status, passwordUpdate, registration, emailVerification, phoneVerification, labels
-        search : str
+        search : Optional[str]
             Search term to filter your list results. Max length: 256 chars.
+        total : Optional[bool]
+            When set to false, the total count returned will be 0 and will not be calculated.
         
         Returns
         -------
@@ -38,26 +40,26 @@ class Users(Service):
 
         api_params['queries'] = queries
         api_params['search'] = search
+        api_params['total'] = total
 
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def create(self, user_id: str, email: str = None, phone: str = None, password: str = None, name: str = None) -> Dict[str, Any]:
+    def create(self, user_id: str, email: Optional[str] = None, phone: Optional[str] = None, password: Optional[str] = None, name: Optional[str] = None) -> Dict[str, Any]:
         """
         Create a new user.
 
-
         Parameters
         ----------
         user_id : str
             User ID. Choose a custom ID or generate a random ID with `ID.unique()`. Valid chars are a-z, A-Z, 0-9, period, hyphen, and underscore. Can't start with a special char. Max length is 36 chars.
-        email : str
+        email : Optional[str]
             User email.
-        phone : str
+        phone : Optional[str]
             Phone number. Format this number with a leading '+' and a country code, e.g., +16175551212.
-        password : str
+        password : Optional[str]
             Plain text user password. Must be at least 8 chars.
-        name : str
+        name : Optional[str]
             User name. Max length: 128 chars.
         
         Returns
@@ -87,11 +89,10 @@ class Users(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def create_argon2_user(self, user_id: str, email: str, password: str, name: str = None) -> Dict[str, Any]:
+    def create_argon2_user(self, user_id: str, email: str, password: str, name: Optional[str] = None) -> Dict[str, Any]:
         """
         Create a new user. Password provided must be hashed with the [Argon2](https://en.wikipedia.org/wiki/Argon2) algorithm. Use the [POST /users](https://appwrite.io/docs/server/users#usersCreate) endpoint to create users with a plain text password.
 
-
         Parameters
         ----------
         user_id : str
@@ -100,7 +101,7 @@ class Users(Service):
             User email.
         password : str
             User password hashed using Argon2.
-        name : str
+        name : Optional[str]
             User name. Max length: 128 chars.
         
         Returns
@@ -135,11 +136,10 @@ class Users(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def create_bcrypt_user(self, user_id: str, email: str, password: str, name: str = None) -> Dict[str, Any]:
+    def create_bcrypt_user(self, user_id: str, email: str, password: str, name: Optional[str] = None) -> Dict[str, Any]:
         """
         Create a new user. Password provided must be hashed with the [Bcrypt](https://en.wikipedia.org/wiki/Bcrypt) algorithm. Use the [POST /users](https://appwrite.io/docs/server/users#usersCreate) endpoint to create users with a plain text password.
 
-
         Parameters
         ----------
         user_id : str
@@ -148,7 +148,7 @@ class Users(Service):
             User email.
         password : str
             User password hashed using Bcrypt.
-        name : str
+        name : Optional[str]
             User name. Max length: 128 chars.
         
         Returns
@@ -183,17 +183,18 @@ class Users(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def list_identities(self, queries: List[str] = None, search: str = None) -> Dict[str, Any]:
+    def list_identities(self, queries: Optional[List[str]] = None, search: Optional[str] = None, total: Optional[bool] = None) -> Dict[str, Any]:
         """
         Get identities for all users.
 
-
         Parameters
         ----------
-        queries : List[str]
+        queries : Optional[List[str]]
             Array of query strings generated using the Query class provided by the SDK. [Learn more about queries](https://appwrite.io/docs/queries). Maximum of 100 queries are allowed, each 4096 characters long. You may filter on the following attributes: userId, provider, providerUid, providerEmail, providerAccessTokenExpiry
-        search : str
+        search : Optional[str]
             Search term to filter your list results. Max length: 256 chars.
+        total : Optional[bool]
+            When set to false, the total count returned will be 0 and will not be calculated.
         
         Returns
         -------
@@ -211,6 +212,7 @@ class Users(Service):
 
         api_params['queries'] = queries
         api_params['search'] = search
+        api_params['total'] = total
 
         return self.client.call('get', api_path, {
         }, api_params)
@@ -219,7 +221,6 @@ class Users(Service):
         """
         Delete an identity by its unique ID.
 
-
         Parameters
         ----------
         identity_id : str
@@ -248,11 +249,10 @@ class Users(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def create_md5_user(self, user_id: str, email: str, password: str, name: str = None) -> Dict[str, Any]:
+    def create_md5_user(self, user_id: str, email: str, password: str, name: Optional[str] = None) -> Dict[str, Any]:
         """
         Create a new user. Password provided must be hashed with the [MD5](https://en.wikipedia.org/wiki/MD5) algorithm. Use the [POST /users](https://appwrite.io/docs/server/users#usersCreate) endpoint to create users with a plain text password.
 
-
         Parameters
         ----------
         user_id : str
@@ -261,7 +261,7 @@ class Users(Service):
             User email.
         password : str
             User password hashed using MD5.
-        name : str
+        name : Optional[str]
             User name. Max length: 128 chars.
         
         Returns
@@ -296,11 +296,10 @@ class Users(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def create_ph_pass_user(self, user_id: str, email: str, password: str, name: str = None) -> Dict[str, Any]:
+    def create_ph_pass_user(self, user_id: str, email: str, password: str, name: Optional[str] = None) -> Dict[str, Any]:
         """
         Create a new user. Password provided must be hashed with the [PHPass](https://www.openwall.com/phpass/) algorithm. Use the [POST /users](https://appwrite.io/docs/server/users#usersCreate) endpoint to create users with a plain text password.
 
-
         Parameters
         ----------
         user_id : str
@@ -309,7 +308,7 @@ class Users(Service):
             User email.
         password : str
             User password hashed using PHPass.
-        name : str
+        name : Optional[str]
             User name. Max length: 128 chars.
         
         Returns
@@ -344,11 +343,10 @@ class Users(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def create_scrypt_user(self, user_id: str, email: str, password: str, password_salt: str, password_cpu: float, password_memory: float, password_parallel: float, password_length: float, name: str = None) -> Dict[str, Any]:
+    def create_scrypt_user(self, user_id: str, email: str, password: str, password_salt: str, password_cpu: float, password_memory: float, password_parallel: float, password_length: float, name: Optional[str] = None) -> Dict[str, Any]:
         """
         Create a new user. Password provided must be hashed with the [Scrypt](https://github.com/Tarsnap/scrypt) algorithm. Use the [POST /users](https://appwrite.io/docs/server/users#usersCreate) endpoint to create users with a plain text password.
 
-
         Parameters
         ----------
         user_id : str
@@ -367,7 +365,7 @@ class Users(Service):
             Optional parallelization cost used to hash password.
         password_length : float
             Optional hash length used to hash password.
-        name : str
+        name : Optional[str]
             User name. Max length: 128 chars.
         
         Returns
@@ -422,11 +420,10 @@ class Users(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def create_scrypt_modified_user(self, user_id: str, email: str, password: str, password_salt: str, password_salt_separator: str, password_signer_key: str, name: str = None) -> Dict[str, Any]:
+    def create_scrypt_modified_user(self, user_id: str, email: str, password: str, password_salt: str, password_salt_separator: str, password_signer_key: str, name: Optional[str] = None) -> Dict[str, Any]:
         """
         Create a new user. Password provided must be hashed with the [Scrypt Modified](https://gist.github.com/Meldiron/eecf84a0225eccb5a378d45bb27462cc) algorithm. Use the [POST /users](https://appwrite.io/docs/server/users#usersCreate) endpoint to create users with a plain text password.
 
-
         Parameters
         ----------
         user_id : str
@@ -441,7 +438,7 @@ class Users(Service):
             Salt separator used to hash password.
         password_signer_key : str
             Signer key used to hash password.
-        name : str
+        name : Optional[str]
             User name. Max length: 128 chars.
         
         Returns
@@ -488,11 +485,10 @@ class Users(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def create_sha_user(self, user_id: str, email: str, password: str, password_version: PasswordHash = None, name: str = None) -> Dict[str, Any]:
+    def create_sha_user(self, user_id: str, email: str, password: str, password_version: Optional[PasswordHash] = None, name: Optional[str] = None) -> Dict[str, Any]:
         """
         Create a new user. Password provided must be hashed with the [SHA](https://en.wikipedia.org/wiki/Secure_Hash_Algorithm) algorithm. Use the [POST /users](https://appwrite.io/docs/server/users#usersCreate) endpoint to create users with a plain text password.
 
-
         Parameters
         ----------
         user_id : str
@@ -501,9 +497,9 @@ class Users(Service):
             User email.
         password : str
             User password hashed using SHA.
-        password_version : PasswordHash
+        password_version : Optional[PasswordHash]
             Optional SHA version used to hash password. Allowed values are: 'sha1', 'sha224', 'sha256', 'sha384', 'sha512/224', 'sha512/256', 'sha512', 'sha3-224', 'sha3-256', 'sha3-384', 'sha3-512'
-        name : str
+        name : Optional[str]
             User name. Max length: 128 chars.
         
         Returns
@@ -543,7 +539,6 @@ class Users(Service):
         """
         Get a user by its unique ID.
 
-
         Parameters
         ----------
         user_id : str
@@ -575,7 +570,6 @@ class Users(Service):
         """
         Delete a user by its unique ID, thereby releasing it's ID. Since ID is released and can be reused, all user-related resources like documents or storage files should be deleted before user deletion. If you want to keep ID reserved, use the [updateStatus](https://appwrite.io/docs/server/users#usersUpdateStatus) endpoint instead.
 
-
         Parameters
         ----------
         user_id : str
@@ -608,7 +602,6 @@ class Users(Service):
         """
         Update the user email by its unique ID.
 
-
         Parameters
         ----------
         user_id : str
@@ -643,18 +636,17 @@ class Users(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def create_jwt(self, user_id: str, session_id: str = None, duration: float = None) -> Dict[str, Any]:
+    def create_jwt(self, user_id: str, session_id: Optional[str] = None, duration: Optional[float] = None) -> Dict[str, Any]:
         """
         Use this endpoint to create a JSON Web Token for user by its unique ID. You can use the resulting JWT to authenticate on behalf of the user. The JWT secret will become invalid if the session it uses gets deleted.
 
-
         Parameters
         ----------
         user_id : str
             User ID.
-        session_id : str
+        session_id : Optional[str]
             Session ID. Use the string 'recent' to use the most recent session. Defaults to the most recent session.
-        duration : float
+        duration : Optional[float]
             Time in seconds before JWT expires. Default duration is 900 seconds, and maximum is 3600 seconds.
         
         Returns
@@ -688,7 +680,6 @@ class Users(Service):
         
         Labels can be used to grant access to resources. While teams are a way for user's to share access to a resource, labels can be defined by the developer to grant access without an invitation. See the [Permissions docs](https://appwrite.io/docs/permissions) for more info.
 
-
         Parameters
         ----------
         user_id : str
@@ -723,17 +714,18 @@ class Users(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def list_logs(self, user_id: str, queries: List[str] = None) -> Dict[str, Any]:
+    def list_logs(self, user_id: str, queries: Optional[List[str]] = None, total: Optional[bool] = None) -> Dict[str, Any]:
         """
         Get the user activity logs list by its unique ID.
 
-
         Parameters
         ----------
         user_id : str
             User ID.
-        queries : List[str]
+        queries : Optional[List[str]]
             Array of query strings generated using the Query class provided by the SDK. [Learn more about queries](https://appwrite.io/docs/queries). Only supported methods are limit and offset
+        total : Optional[bool]
+            When set to false, the total count returned will be 0 and will not be calculated.
         
         Returns
         -------
@@ -754,23 +746,25 @@ class Users(Service):
         api_path = api_path.replace('{userId}', user_id)
 
         api_params['queries'] = queries
+        api_params['total'] = total
 
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def list_memberships(self, user_id: str, queries: List[str] = None, search: str = None) -> Dict[str, Any]:
+    def list_memberships(self, user_id: str, queries: Optional[List[str]] = None, search: Optional[str] = None, total: Optional[bool] = None) -> Dict[str, Any]:
         """
         Get the user membership list by its unique ID.
 
-
         Parameters
         ----------
         user_id : str
             User ID.
-        queries : List[str]
+        queries : Optional[List[str]]
             Array of query strings generated using the Query class provided by the SDK. [Learn more about queries](https://appwrite.io/docs/queries). Maximum of 100 queries are allowed, each 4096 characters long. You may filter on the following attributes: userId, teamId, invited, joined, confirm, roles
-        search : str
+        search : Optional[str]
             Search term to filter your list results. Max length: 256 chars.
+        total : Optional[bool]
+            When set to false, the total count returned will be 0 and will not be calculated.
         
         Returns
         -------
@@ -792,6 +786,7 @@ class Users(Service):
 
         api_params['queries'] = queries
         api_params['search'] = search
+        api_params['total'] = total
 
         return self.client.call('get', api_path, {
         }, api_params)
@@ -800,7 +795,6 @@ class Users(Service):
         """
         Enable or disable MFA on a user account.
 
-
         Parameters
         ----------
         user_id : str
@@ -839,7 +833,6 @@ class Users(Service):
         """
         Delete an authenticator app.
 
-
         Parameters
         ----------
         user_id : str
@@ -878,7 +871,6 @@ class Users(Service):
         """
         List the factors available on the account to be used as a MFA challange.
 
-
         Parameters
         ----------
         user_id : str
@@ -910,7 +902,6 @@ class Users(Service):
         """
         Get recovery codes that can be used as backup for MFA flow by User ID. Before getting codes, they must be generated using [createMfaRecoveryCodes](/docs/references/cloud/client-web/account#createMfaRecoveryCodes) method.
 
-
         Parameters
         ----------
         user_id : str
@@ -942,7 +933,6 @@ class Users(Service):
         """
         Regenerate recovery codes that can be used as backup for MFA flow by User ID. Before regenerating codes, they must be first generated using [createMfaRecoveryCodes](/docs/references/cloud/client-web/account#createMfaRecoveryCodes) method.
 
-
         Parameters
         ----------
         user_id : str
@@ -975,7 +965,6 @@ class Users(Service):
         """
         Generate recovery codes used as backup for MFA flow for User ID. Recovery codes can be used as a MFA verification type in [createMfaChallenge](/docs/references/cloud/client-web/account#createMfaChallenge) method by client SDK.
 
-
         Parameters
         ----------
         user_id : str
@@ -1008,7 +997,6 @@ class Users(Service):
         """
         Update the user name by its unique ID.
 
-
         Parameters
         ----------
         user_id : str
@@ -1047,7 +1035,6 @@ class Users(Service):
         """
         Update the user password by its unique ID.
 
-
         Parameters
         ----------
         user_id : str
@@ -1086,7 +1073,6 @@ class Users(Service):
         """
         Update the user phone by its unique ID.
 
-
         Parameters
         ----------
         user_id : str
@@ -1125,7 +1111,6 @@ class Users(Service):
         """
         Get the user preferences by its unique ID.
 
-
         Parameters
         ----------
         user_id : str
@@ -1157,7 +1142,6 @@ class Users(Service):
         """
         Update the user preferences by its unique ID. The object you pass is stored as is, and replaces any previous value. The maximum allowed prefs size is 64kB and throws error if exceeded.
 
-
         Parameters
         ----------
         user_id : str
@@ -1192,15 +1176,16 @@ class Users(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def list_sessions(self, user_id: str) -> Dict[str, Any]:
+    def list_sessions(self, user_id: str, total: Optional[bool] = None) -> Dict[str, Any]:
         """
         Get the user sessions list by its unique ID.
 
-
         Parameters
         ----------
         user_id : str
             User ID.
+        total : Optional[bool]
+            When set to false, the total count returned will be 0 and will not be calculated.
         
         Returns
         -------
@@ -1220,6 +1205,7 @@ class Users(Service):
 
         api_path = api_path.replace('{userId}', user_id)
 
+        api_params['total'] = total
 
         return self.client.call('get', api_path, {
         }, api_params)
@@ -1230,7 +1216,6 @@ class Users(Service):
         
         If you want to generate a token for a custom authentication flow, use the [POST /users/{userId}/tokens](https://appwrite.io/docs/server/users#createToken) endpoint.
 
-
         Parameters
         ----------
         user_id : str
@@ -1263,7 +1248,6 @@ class Users(Service):
         """
         Delete all user's sessions by using the user's unique ID.
 
-
         Parameters
         ----------
         user_id : str
@@ -1296,7 +1280,6 @@ class Users(Service):
         """
         Delete a user sessions by its unique ID.
 
-
         Parameters
         ----------
         user_id : str
@@ -1335,7 +1318,6 @@ class Users(Service):
         """
         Update the user status by its unique ID. Use this endpoint as an alternative to deleting a user if you want to keep user's ID reserved.
 
-
         Parameters
         ----------
         user_id : str
@@ -1370,17 +1352,18 @@ class Users(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def list_targets(self, user_id: str, queries: List[str] = None) -> Dict[str, Any]:
+    def list_targets(self, user_id: str, queries: Optional[List[str]] = None, total: Optional[bool] = None) -> Dict[str, Any]:
         """
         List the messaging targets that are associated with a user.
 
-
         Parameters
         ----------
         user_id : str
             User ID.
-        queries : List[str]
+        queries : Optional[List[str]]
             Array of query strings generated using the Query class provided by the SDK. [Learn more about queries](https://appwrite.io/docs/queries). Maximum of 100 queries are allowed, each 4096 characters long. You may filter on the following attributes: userId, providerId, identifier, providerType
+        total : Optional[bool]
+            When set to false, the total count returned will be 0 and will not be calculated.
         
         Returns
         -------
@@ -1401,15 +1384,15 @@ class Users(Service):
         api_path = api_path.replace('{userId}', user_id)
 
         api_params['queries'] = queries
+        api_params['total'] = total
 
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def create_target(self, user_id: str, target_id: str, provider_type: MessagingProviderType, identifier: str, provider_id: str = None, name: str = None) -> Dict[str, Any]:
+    def create_target(self, user_id: str, target_id: str, provider_type: MessagingProviderType, identifier: str, provider_id: Optional[str] = None, name: Optional[str] = None) -> Dict[str, Any]:
         """
         Create a messaging target.
 
-
         Parameters
         ----------
         user_id : str
@@ -1420,9 +1403,9 @@ class Users(Service):
             The target provider type. Can be one of the following: `email`, `sms` or `push`.
         identifier : str
             The target identifier (token, email, phone etc.)
-        provider_id : str
+        provider_id : Optional[str]
             Provider ID. Message will be sent to this target from the specified provider ID. If no provider ID is set the first setup provider will be used.
-        name : str
+        name : Optional[str]
             Target name. Max length: 128 chars. For example: My Awesome App Galaxy S23.
         
         Returns
@@ -1466,7 +1449,6 @@ class Users(Service):
         """
         Get a user's push notification target by ID.
 
-
         Parameters
         ----------
         user_id : str
@@ -1500,22 +1482,21 @@ class Users(Service):
         return self.client.call('get', api_path, {
         }, api_params)
 
-    def update_target(self, user_id: str, target_id: str, identifier: str = None, provider_id: str = None, name: str = None) -> Dict[str, Any]:
+    def update_target(self, user_id: str, target_id: str, identifier: Optional[str] = None, provider_id: Optional[str] = None, name: Optional[str] = None) -> Dict[str, Any]:
         """
         Update a messaging target.
 
-
         Parameters
         ----------
         user_id : str
             User ID.
         target_id : str
             Target ID.
-        identifier : str
+        identifier : Optional[str]
             The target identifier (token, email, phone etc.)
-        provider_id : str
+        provider_id : Optional[str]
             Provider ID. Message will be sent to this target from the specified provider ID. If no provider ID is set the first setup provider will be used.
-        name : str
+        name : Optional[str]
             Target name. Max length: 128 chars. For example: My Awesome App Galaxy S23.
         
         Returns
@@ -1552,7 +1533,6 @@ class Users(Service):
         """
         Delete a messaging target.
 
-
         Parameters
         ----------
         user_id : str
@@ -1587,19 +1567,18 @@ class Users(Service):
             'content-type': 'application/json',
         }, api_params)
 
-    def create_token(self, user_id: str, length: float = None, expire: float = None) -> Dict[str, Any]:
+    def create_token(self, user_id: str, length: Optional[float] = None, expire: Optional[float] = None) -> Dict[str, Any]:
         """
         Returns a token with a secret key for creating a session. Use the user ID and secret and submit a request to the [PUT /account/sessions/token](https://appwrite.io/docs/references/cloud/client-web/account#createSession) endpoint to complete the login process.
         
 
-
         Parameters
         ----------
         user_id : str
             User ID.
-        length : float
+        length : Optional[float]
             Token length in characters. The default length is 6 characters
-        expire : float
+        expire : Optional[float]
             Token expiration period in seconds. The default expiration is 15 minutes.
         
         Returns
@@ -1631,7 +1610,6 @@ class Users(Service):
         """
         Update the user email verification status by its unique ID.
 
-
         Parameters
         ----------
         user_id : str
@@ -1670,7 +1648,6 @@ class Users(Service):
         """
         Update the user phone verification status by its unique ID.
 
-
         Parameters
         ----------
         user_id : str
